#
# spec file for package zypp-plugin-spacewalk
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python2_sitelib: %global python2_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%if 0%{?suse_version} > 1320
%bcond_without python3
%bcond_with rhnpath
%global py2_actions %{python2_sitelib}/rhn
%global py3_actions %{python3_sitelib}/rhn
%define pythonX python3
%else
%bcond_with python3
%bcond_with rhnpath
%if %{with rhnpath}
%global py2_actions %{_datadir}/rhn/
%else
%define pythonX python2
%global py2_actions %{python2_sitelib}/rhn
%endif
%endif

Name:           zypp-plugin-spacewalk
Version:        1.0.9
Release:        3.18.1
Summary:        Client side Spacewalk integration for ZYpp
License:        GPL-2.0-only
Group:          System Environment/Base
URL:            https://github.com/openSUSE/zypp-plugin-spacewalk
Source0:        zypp-plugin-spacewalk.tar.bz2
Source1:        zypp-plugin-spacewalk-rpmlintrc
# Actually needs just libzypp, but we also want zypper to
# handle services correctly:
%if 0%{?suse_version} == 1010
# on SLES10 require basic code10->11 metadata conversion tools
Requires:       libzypp(code10)
# esp. for OES we need to provide zmd as it's required by the
# products -release package. :(
Provides:       zmd <= 7.3.0.0
%endif
%if 0%{?suse_version} == 1110 || 0%{?suse_version} == 1010
# on SLES11-SP1
# on SLES10-SP3
BuildRequires:  libzypp >= 6.35.0
Requires:       zypper >= 1.3.12
%else
# since 11.4
BuildRequires:  libzypp >= 8.12.0
Requires:       zypper >= 1.5.3
%endif
%if 0%{?sle_version} >= 120000
# SLES12+
Requires:       zypper(updatestack-only)
%endif
Requires:       zypper(oldpackage)

%if %{without python3}
Requires:       python
Requires:       python-xml
Requires:       rhn-client-tools >= 1.7.7
Requires:       rhnlib
Requires:       zypp-plugin-python
BuildRequires:  python-devel
%else
Requires:       python3
Requires:       python3-rhnlib
Requires:       python3-zypp-plugin
Requires:       rhn-client-tools >= 2.8.4
BuildRequires:  python3-devel
%endif
%if %{without rhnpath}
Requires:       %{pythonX}-%{name} = %{version}-%{release}
%endif

Provides:       zypp-media-plugin(spacewalk) = %{version}
Provides:       zypp-service-plugin(spacewalk) = %{version}
%if 0%{?suse_version} >= 1210
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This plugin allows a ZYpp powered Linux system to see Spacewalk
subscribed repositories as well as downloading packages from the
a Spacewalk compatible server.

%if %{without rhnpath}
%package -n python2-%{name}
Summary:        Client side Spacewalk integration for ZYpp
Group:          System Environment/Base
Requires:       %{name} = %{version}-%{release}
Requires:       python2-rhn-client-tools >= 2.8.4
BuildRequires:  python-devel

%description -n python2-%{name}
Python 2 specific files of %{name}
%endif

%if %{with python3}
%package -n python3-%{name}
Summary:        Client side Spacewalk integration for ZYpp
Group:          System Environment/Base
Requires:       %{name} = %{version}-%{release}
BuildRequires:  python3-devel
Requires:       python3
Requires:       python3-rhn-client-tools >= 2.8.4

%description -n python3-%{name}
Python 3 specific files of %{name}
%endif

%prep
%setup -q -n zypp-plugin-spacewalk

%build
%if %{with python3}
grep -E -r -l "\#\!\s*/usr/bin/env\s+python" * | xargs -i -d "\n" sed -i -e"s:\#\![ \t]*/usr/bin/env[ \t]\+python:\#\!/usr/bin/python3:" {}
%else
grep -E -r -l "\#\!\s*/usr/bin/env\s+python" * | xargs -i -d "\n" sed -i -e"s:\#\![ \t]*/usr/bin/env[ \t]\+python:\#\!/usr/bin/python:" {}
%endif

%install
%{__mkdir_p} %{buildroot}%{_prefix}/lib/zypp/plugins/services
%{__mkdir_p} %{buildroot}%{_prefix}/lib/zypp/plugins/system
%{__mkdir_p} %{buildroot}%{_prefix}/lib/zypp/plugins/urlresolver
%{__mkdir_p} %{buildroot}%{_sysconfdir}/sysconfig/rhn/clientCaps.d/

%{__install} bin/spacewalk-service.py %{buildroot}%{_prefix}/lib/zypp/plugins/services/spacewalk
%{__install} bin/spacewalk-system.py %{buildroot}%{_prefix}/lib/zypp/plugins/system/spacewalk
%{__install} bin/spacewalk-resolver.py %{buildroot}%{_prefix}/lib/zypp/plugins/urlresolver/spacewalk

%{__mkdir_p} %{buildroot}%{py2_actions}/actions
%{__install} actions/packages.py %{buildroot}%{py2_actions}/actions/
%{__install} actions/errata.py %{buildroot}%{py2_actions}/actions/
%{__install} actions/distupgrade.py %{buildroot}%{py2_actions}/actions/

%if %{with python3}
%{__mkdir_p} %{buildroot}%{py3_actions}/actions
%{__install} actions/packages.py %{buildroot}%{py3_actions}/actions/
%{__install} actions/errata.py %{buildroot}%{py3_actions}/actions/
%{__install} actions/distupgrade.py %{buildroot}%{py3_actions}/actions/
%endif

%{__install} -m 0644 clientCaps/packages %{buildroot}%{_sysconfdir}/sysconfig/rhn/clientCaps.d/
%if 0%{?sle_version} >= 120000
%{__install} -m 0644 clientCaps/distupgrade2 %{buildroot}%{_sysconfdir}/sysconfig/rhn/clientCaps.d/distupgrade
%else
%{__install} -m 0644 clientCaps/distupgrade %{buildroot}%{_sysconfdir}/sysconfig/rhn/clientCaps.d/
%endif

%{__mkdir_p} %{buildroot}%{_var}/lib/up2date

%if 0%{?suse_version}
%py_compile %{buildroot}%{py2_actions}
%if %{with python3}
%py3_compile %{buildroot}/%{py3_actions}
%endif
%endif

%files
%defattr(-,root,root)
%doc COPYING
%dir %{_prefix}/lib/zypp
%dir %{_prefix}/lib/zypp/plugins
%dir %{_prefix}/lib/zypp/plugins/services
     %{_prefix}/lib/zypp/plugins/services/spacewalk
%dir %{_prefix}/lib/zypp/plugins/system
     %{_prefix}/lib/zypp/plugins/system/spacewalk
%dir %{_prefix}/lib/zypp/plugins/urlresolver
     %{_prefix}/lib/zypp/plugins/urlresolver/spacewalk
%if %{with rhnpath}
%dir %{_datadir}/rhn
%dir %{_datadir}/rhn/actions
     %{_datadir}/rhn/actions/packages.py*
     %{_datadir}/rhn/actions/errata.py*
     %{_datadir}/rhn/actions/distupgrade.py*
%endif
%dir %{_var}/lib/up2date
%dir %{_sysconfdir}/sysconfig/rhn
%dir %{_sysconfdir}/sysconfig/rhn/clientCaps.d
%config %{_sysconfdir}/sysconfig/rhn/clientCaps.d/packages
%config %{_sysconfdir}/sysconfig/rhn/clientCaps.d/distupgrade

%if %{without rhnpath}
%files -n python2-%{name}
%defattr(-,root,root)
%dir %{py2_actions}
%dir %{py2_actions}/actions
     %{py2_actions}/actions/packages.py*
     %{py2_actions}/actions/errata.py*
     %{py2_actions}/actions/distupgrade.py*
%endif

%if %{with python3}
%files -n python3-%{name}
%defattr(-,root,root)
%dir %{py3_actions}
%dir %{py3_actions}/actions
%dir %{py3_actions}/actions/__pycache__
     %{py3_actions}/actions/packages.py*
     %{py3_actions}/actions/errata.py*
     %{py3_actions}/actions/distupgrade.py*
     %{py3_actions}/actions/__pycache__/*.py*
%endif

%changelog
* Fri Mar 12 2021 mseidl@suse.de
- 1.0.9
- support for "allow vendor change" for patching/upgrading
* Thu Oct  8 2020 mseidl@suse.de
- 1.0.8
- support "allow vendor change" for dist upgrades
* Fri Jun  5 2020 pablo.suarezhernandez@suse.com
- 1.0.7
- Prevent issue with non-ASCII characters in Python 2 systems (bsc#1172462)
* Fri Oct 25 2019 pablo.suarezhernandez@suse.com
- 1.0.6
- Prevent possible encoding issues on Python 3 (bsc#1152722)
* Thu May 23 2019 psuarezhernandez@suse.com
- 1.0.5
- Fix python syntax error in distupgrade (bsc#1136102)
* Tue Jul 10 2018 mc@suse.com
- 1.0.4
- turn on metadata signature checking if signature is available
* Thu May  3 2018 mc@suse.com
- 1.0.3
- fix encoding errors with python3 (bsc#1090746)
* Wed May  2 2018 mc@suse.com
- 1.0.2
- use standard python path for actions also when building
  for older distributions (bsc#1091665)
* Thu Apr 26 2018 mc@suse.com
- 1.0.1
- change pkg_gpgcheck setting to restore the old behaviour with
  upstream Spacewalk (bsc#1091034)
* Thu Sep 28 2017 mc@suse.com
- 1.0.0
- python3 compatibility (bsc#1073879)
- build python2/python3 subpackages
- build as noarch for SLES12 and higher
* Mon Aug  7 2017 ma@suse.com
- Fix setting pkg_gpgcheck
- 0.9.16
* Tue Aug  1 2017 mantel@suse.de
- make pkg_gpgcheck configurable
- 0.9.15
* Tue May  3 2016 mantel@suse.de
- fix failover for multiple URLs per repo (bsc#964932)
* Fri Jan 22 2016 mc@suse.de
- adapt for up2date client changes
- 0.9.13
* Fri Dec 11 2015 mc@suse.de
- convert zypper output to valid UTF-8 (bsc#954602)
- 0.9.12
* Mon Oct 19 2015 mc@suse.de
- use sle_version macro to detect SLE12
* Sat Sep 12 2015 mc@suse.de
- support distribution upgrade with --no-allow-vendor-change
  for sle12 (FATE#319128)
- 0.9.11
* Mon Aug 31 2015 ma@suse.com
- fix output of client events (bsc#935377)
- 0.9.10
* Wed Apr 29 2015 dmacvicar@suse.de
- check for package signatures when metadata is not signed
  (fate#314603)
- fix build check warnings:
  * use SPDX license name (GPL-2.0)
  * egrep usage
- 0.9.9
* Mon Sep 15 2014 mc@suse.de
- check for retrieveOnly option in up2date conf and set
  download_only (bnc#896254)
* Wed Aug 13 2014 fcastelli@suse.de
- Changed the spec file to force usage of the official python VM; do
  no longer use "!#/usr/bin/env python" as shebang. (bnc#889363)
* Tue May 13 2014 mc@suse.de
- require rhn-client-tools >= 1.7.7 which contains utf8_encode
  function (bnc#850105)
* Thu Apr 24 2014 ma@suse.de
- Fixed package lock
- version 0.9.8
* Thu Apr 10 2014 ma@suse.de
- Fix package locking on SLE10
- version 0.9.7
* Wed Jan  8 2014 ma@suse.de
- Prepare packages.setLocks action for SUMA-2.1 (fate#312359)
- version to 0.9.6
* Wed Dec 11 2013 mc@suse.de
- install COPYING file
* Mon Dec  2 2013 ma@suse.de
- bump version to 0.9.5
* Thu Nov 14 2013 fcastelli@suse.com
- version 0.9.4
- Avoid crashes when a channel's metadata contains UTF-8 data. (bnc#850105)
* Thu Oct 24 2013 mc@suse.de
- version 0.9.3
- call zypper with --auto-agree-with-licenses, because interactive
  aggreement is not possible from remote. (bnc#847254)
* Mon Jun 10 2013 ma@suse.de
- Always disable gpgcheck for repos in spacewalk service (bnc#823917)
- version 0.9.2
* Tue Apr 23 2013 mc@suse.de
- use timeout also for XMLRPC calles if possible (bnc#815460)
* Fri Apr 19 2013 mc@suse.de
- read transfer_timeout from zypp.conf and provide it
  via URL (bnc#815460)
* Fri Feb 15 2013 dmacvicar@suse.de
- version 0.9.1
- Handle the cache_only flag to actions correctly.
  Prevents some future actions to be executed immediately.
  (bnc#803941)
* Wed Jan 30 2013 mc@suse.de
- version 0.9
- use new zypper option --oldpackage to support package
  downgrades (bnc#795076)
- compile python code
* Fri Nov 23 2012 ma@suse.de
- version 0.8
* Tue Oct  2 2012 mc@suse.de
- map zypper patch exit code 103 to 0
  restart of the software management stack happens automatically
  if zypper exits
* Fri Sep 21 2012 mc@suse.de
- try to restart spacewalksd and osad after distupgrade action
* Wed Jun 27 2012 mc@suse.de
- add rpmlintrc
* Tue Jun 19 2012 mc@suse.de
- version 0.7
- add distupgrade action and capability
* Tue Apr  3 2012 ma@suse.de
- Use versioned provides for zmd hack (bnc#743955)
* Mon Jan 30 2012 ma@suse.de
- Code10: Provide 'zmd' to aid products requiring this in their
  release package. (bnc#743955)
* Mon Nov 21 2011 ma@suse.de
- Fix bug in spacewalk-action-package breaking spacewalk synchronize
  profile. (bnc#731714)
- version 0.5
* Thu Jul  7 2011 ma@suse.de
- Catch client not being registered or spacewalk-backend-libs missing.
* Wed Jul  6 2011 mc@suse.de
- fix wrong variable initialization
* Mon Jul  4 2011 ma@suse.de
- Fix wrong import paths for import Plugin.
- Remove zypp-plugin from specfile (stand alone package now).
- version 0.4
* Thu Jun 30 2011 dmacvicar@suse.de
- split zypp-plugin-python as a subpackage so
  that it can be used in other zypp plugins like snapper
- version 0.3
* Wed Jun 29 2011 iartarisi@suse.cz
- install patches using 'zypper install patch:' (bnc#692928)
* Fri Jun 17 2011 ma@suse.de
- On SLE10 require libzypp basic code10->11 metadata conversion tools.
* Fri Jun  3 2011 ma@suse.de
- Provide zypp-plugin-python, which should become a standalone
  package providing the python Plugin base class.
- python Plugin: Redirect stdin to stderr to prevent modules from
  sending garbage back to libzypp. Return _ENOMETHOD if some message
  handler is not implemented by the plugin. Close stdin and leave the
  main loop when receiving a _DISCONNECT message.
- version 0.2
* Tue May 31 2011 dmacvicar@suse.de
- add python-xml as requirement (for minidom)
* Wed Apr 27 2011 ma@suse.de
- Fix build requires on SLE10
* Wed Apr  6 2011 ma@suse.de
- fix channel url usage; might be a list type.
* Tue Mar  1 2011 ma@suse.de
- Fix build requires
* Thu Feb 17 2011 ma@suse.de
- Fix debug output from rhn_check disturbing zypper (bnc#672019)
* Wed Jan 26 2011 ma@suse.de
- Require a zypper version that correctly handles service refresh.
  The plugin itself does not need zypper, but if you use the plugin
  you also want your zypper to be in shape.
* Wed Jan 12 2011 ma@suse.de
- Fix KeyErrors
* Fri Nov 26 2010 ma@suse.de
- Fix missing import (bnc#656066)
* Tue Nov  9 2010 ma@suse.de
- Add /var/lib/up2date directory to filelist.
* Thu Sep 30 2010 dmacvicar@novell.com
- initial version
